/****************************************************************************
**
** Copyright (C) 2016 The Qt Company Ltd.
** Contact: https://www.qt.io/licensing/
**
** This file is part of Qt for Python.
**
** $QT_BEGIN_LICENSE:LGPL$
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 3 as published by the Free Software
** Foundation and appearing in the file LICENSE.LGPL3 included in the
** packaging of this file. Please review the following information to
** ensure the GNU Lesser General Public License version 3 requirements
** will be met: https://www.gnu.org/licenses/lgpl-3.0.html.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 2.0 or (at your option) the GNU General
** Public license version 3 or any later version approved by the KDE Free
** Qt Foundation. The licenses are as published by the Free Software
** Foundation and appearing in the file LICENSE.GPL2 and LICENSE.GPL3
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-2.0.html and
** https://www.gnu.org/licenses/gpl-3.0.html.
**
** $QT_END_LICENSE$
**
****************************************************************************/

//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QDebug>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <destroylistener.h>
#include <qapp_macro.h>
#include <typeinfo>

// module include
#include "pyside2_qt3danimation_python.h"

// main header
#include "qt3danimation_qskeletonmapping_wrapper.h"

// inner classes

// Extra includes
#include <Qt3DCore/qabstractskeleton.h>
#include <Qt3DCore/qnode.h>
#include <QtCore/qobject.h>


#include <cctype>
#include <cstring>

QT_WARNING_DISABLE_DEPRECATED
using namespace Qt3DAnimation;



template <class T>
static const char *typeNameOf(const T &t)
{
    const char *typeName =  typeid(t).name();
    auto size = std::strlen(typeName);
#if defined(Q_CC_MSVC) // MSVC: "class QPaintDevice * __ptr64"
    if (auto lastStar = strchr(typeName, '*')) {
        // MSVC: "class QPaintDevice * __ptr64"
        while (*--lastStar == ' ') {
        }
        size = lastStar - typeName + 1;
    }
#else // g++, Clang: "QPaintDevice *" -> "P12QPaintDevice"
    if (size > 2 && typeName[0] == 'P' && std::isdigit(typeName[1])) {
        ++typeName;
        --size;
    }
#endif
    char *result = new char[size + 1];
    result[size] = '\0';
    memcpy(result, typeName, size);
    return result;
}

// Native ---------------------------------------------------------

QSkeletonMappingWrapper::QSkeletonMappingWrapper(Qt3DCore::QNode * parent) : Qt3DAnimation::QSkeletonMapping(parent)
{
    // ... middle
}

QSkeletonMappingWrapper::~QSkeletonMappingWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_Qt3DAnimation_QSkeletonMapping_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SbkObject *sbkSelf = reinterpret_cast<SbkObject *>(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::Qt3DAnimation::QSkeletonMapping >()))
        return -1;

    ::QSkeletonMappingWrapper *cptr{};
    int overloadId = -1;
    PythonToCppFunc pythonToCpp[] = { nullptr };
    SBK_UNUSED(pythonToCpp)
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 1) {
        PyErr_SetString(PyExc_TypeError, "PySide2.Qt3DAnimation.Qt3DAnimation.QSkeletonMapping(): too many arguments");
        return -1;
    }

    if (!PyArg_ParseTuple(args, "|O:QSkeletonMapping", &(pyArgs[0])))
        return -1;


    // Overloaded function decisor
    // 0: QSkeletonMapping::QSkeletonMapping(Qt3DCore::QNode*)
    if (numArgs == 0) {
        overloadId = 0; // QSkeletonMapping(Qt3DCore::QNode*)
    } else if ((pythonToCpp[0] = Shiboken::Conversions::isPythonToCppPointerConvertible(reinterpret_cast<SbkObjectType *>(SbkPySide2_Qt3DCoreTypes[SBK_QT3DCORE_QNODE_IDX]), (pyArgs[0])))) {
        overloadId = 0; // QSkeletonMapping(Qt3DCore::QNode*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_Qt3DAnimation_QSkeletonMapping_Init_TypeError;

    // Call function/method
    {
        if (kwds) {
            PyObject *keyName = nullptr;
            PyObject *value = nullptr;
            keyName = Py_BuildValue("s","parent");
            if (PyDict_Contains(kwds, keyName)) {
            value = PyDict_GetItemString(kwds, "parent");
            if (value && pyArgs[0]) {
                PyErr_SetString(PyExc_TypeError, "PySide2.Qt3DAnimation.Qt3DAnimation.QSkeletonMapping(): got multiple values for keyword argument 'parent'.");
                return -1;
                        } else if (value) {
                pyArgs[0] = value;
                if (!(pythonToCpp[0] = Shiboken::Conversions::isPythonToCppPointerConvertible(reinterpret_cast<SbkObjectType *>(SbkPySide2_Qt3DCoreTypes[SBK_QT3DCORE_QNODE_IDX]), (pyArgs[0]))))
                    goto Sbk_Qt3DAnimation_QSkeletonMapping_Init_TypeError;
            }
}
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return -1;
        ::Qt3DCore::QNode *cppArg0 = nullptr;
        if (pythonToCpp[0]) pythonToCpp[0](pyArgs[0], &cppArg0);

        if (!PyErr_Occurred()) {
            // QSkeletonMapping(Qt3DCore::QNode*)
            PyThreadState *_save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cptr = new ::QSkeletonMappingWrapper(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            Shiboken::Object::setParent(pyArgs[0], self);
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::Qt3DAnimation::QSkeletonMapping >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto Sbk_Qt3DAnimation_QSkeletonMapping_Init_TypeError;

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    Sbk_Qt3DAnimation_QSkeletonMapping_Init_TypeError:
        Shiboken::setErrorAboutWrongArguments(args, "PySide2.Qt3DAnimation.Qt3DAnimation.QSkeletonMapping");
        return -1;
}

static PyObject *Sbk_Qt3DAnimation_QSkeletonMappingFunc_setSkeleton(PyObject *self, PyObject *pyArg)
{
    ::Qt3DAnimation::QSkeletonMapping *cppSelf = nullptr;
    SBK_UNUSED(cppSelf)
    if (!Shiboken::Object::isValid(self))
        return {};
    cppSelf = reinterpret_cast< ::Qt3DAnimation::QSkeletonMapping *>(Shiboken::Conversions::cppPointer(SbkPySide2_Qt3DAnimationTypes[SBK_QT3DANIMATION_QSKELETONMAPPING_IDX], reinterpret_cast<SbkObject *>(self)));
    int overloadId = -1;
    PythonToCppFunc pythonToCpp{};
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSkeletonMapping::setSkeleton(Qt3DCore::QAbstractSkeleton*)
    if ((pythonToCpp = Shiboken::Conversions::isPythonToCppPointerConvertible(reinterpret_cast<SbkObjectType *>(SbkPySide2_Qt3DCoreTypes[SBK_QT3DCORE_QABSTRACTSKELETON_IDX]), (pyArg)))) {
        overloadId = 0; // setSkeleton(Qt3DCore::QAbstractSkeleton*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_Qt3DAnimation_QSkeletonMappingFunc_setSkeleton_TypeError;

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::Qt3DCore::QAbstractSkeleton *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (!PyErr_Occurred()) {
            // setSkeleton(Qt3DCore::QAbstractSkeleton*)
            PyThreadState *_save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cppSelf->setSkeleton(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return {};
    }
    Py_RETURN_NONE;

    Sbk_Qt3DAnimation_QSkeletonMappingFunc_setSkeleton_TypeError:
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide2.Qt3DAnimation.Qt3DAnimation.QSkeletonMapping.setSkeleton");
        return {};
}

static PyObject *Sbk_Qt3DAnimation_QSkeletonMappingFunc_skeleton(PyObject *self)
{
    ::Qt3DAnimation::QSkeletonMapping *cppSelf = nullptr;
    SBK_UNUSED(cppSelf)
    if (!Shiboken::Object::isValid(self))
        return {};
    cppSelf = reinterpret_cast< ::Qt3DAnimation::QSkeletonMapping *>(Shiboken::Conversions::cppPointer(SbkPySide2_Qt3DAnimationTypes[SBK_QT3DANIMATION_QSKELETONMAPPING_IDX], reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};

    // Call function/method
    {

        if (!PyErr_Occurred()) {
            // skeleton()const
            Qt3DCore::QAbstractSkeleton * cppResult = const_cast<const ::Qt3DAnimation::QSkeletonMapping *>(cppSelf)->skeleton();
            pyResult = Shiboken::Conversions::pointerToPython(reinterpret_cast<SbkObjectType *>(SbkPySide2_Qt3DCoreTypes[SBK_QT3DCORE_QABSTRACTSKELETON_IDX]), cppResult);
            Shiboken::Object::setParent(self, pyResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyMethodDef Sbk_Qt3DAnimation_QSkeletonMapping_methods[] = {
    {"setSkeleton", reinterpret_cast<PyCFunction>(Sbk_Qt3DAnimation_QSkeletonMappingFunc_setSkeleton), METH_O},
    {"skeleton", reinterpret_cast<PyCFunction>(Sbk_Qt3DAnimation_QSkeletonMappingFunc_skeleton), METH_NOARGS},

    {nullptr, nullptr} // Sentinel
};

} // extern "C"

static int Sbk_Qt3DAnimation_QSkeletonMapping_traverse(PyObject *self, visitproc visit, void *arg)
{
    return reinterpret_cast<PyTypeObject *>(SbkObject_TypeF())->tp_traverse(self, visit, arg);
}
static int Sbk_Qt3DAnimation_QSkeletonMapping_clear(PyObject *self)
{
    return reinterpret_cast<PyTypeObject *>(SbkObject_TypeF())->tp_clear(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType *_Sbk_Qt3DAnimation_QSkeletonMapping_Type = nullptr;
static SbkObjectType *Sbk_Qt3DAnimation_QSkeletonMapping_TypeF(void)
{
    return _Sbk_Qt3DAnimation_QSkeletonMapping_Type;
}

static PyType_Slot Sbk_Qt3DAnimation_QSkeletonMapping_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_repr,        nullptr},
    {Py_tp_hash,        nullptr},
    {Py_tp_call,        nullptr},
    {Py_tp_str,         nullptr},
    {Py_tp_getattro,    nullptr},
    {Py_tp_setattro,    nullptr},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_Qt3DAnimation_QSkeletonMapping_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_Qt3DAnimation_QSkeletonMapping_clear)},
    {Py_tp_richcompare, nullptr},
    {Py_tp_iter,        nullptr},
    {Py_tp_iternext,    nullptr},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_Qt3DAnimation_QSkeletonMapping_methods)},
    {Py_tp_getset,      nullptr},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_Qt3DAnimation_QSkeletonMapping_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObjectTpNew)},
    {0, nullptr}
};
static PyType_Spec Sbk_Qt3DAnimation_QSkeletonMapping_spec = {
    "PySide2.Qt3DAnimation.Qt3DAnimation.QSkeletonMapping",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_GC,
    Sbk_Qt3DAnimation_QSkeletonMapping_slots
};

} //extern "C"


// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QSkeletonMapping_PythonToCpp_QSkeletonMapping_PTR(PyObject *pyIn, void *cppOut) {
    Shiboken::Conversions::pythonToCppPointer(Sbk_Qt3DAnimation_QSkeletonMapping_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QSkeletonMapping_PythonToCpp_QSkeletonMapping_PTR_Convertible(PyObject *pyIn) {
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, reinterpret_cast<PyTypeObject *>(Sbk_Qt3DAnimation_QSkeletonMapping_TypeF())))
        return QSkeletonMapping_PythonToCpp_QSkeletonMapping_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QSkeletonMapping_PTR_CppToPython_QSkeletonMapping(const void *cppIn) {
    auto pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    bool changedTypeName = false;
    auto tCppIn = reinterpret_cast<const ::Qt3DAnimation::QSkeletonMapping *>(cppIn);
    const char *typeName = typeid(*tCppIn).name();
    auto sbkType = Shiboken::ObjectType::typeForTypeName(typeName);
    if (sbkType && Shiboken::ObjectType::hasSpecialCastFunction(sbkType)) {
        typeName = typeNameOf(tCppIn);
        changedTypeName = true;
     }
    PyObject *result = Shiboken::Object::newObject(Sbk_Qt3DAnimation_QSkeletonMapping_TypeF(), const_cast<void *>(cppIn), false, /* exactType */ changedTypeName, typeName);
    if (changedTypeName)
        delete [] typeName;
    return result;
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
static const char *Qt3DAnimation_QSkeletonMapping_SignatureStrings[] = {
    "PySide2.Qt3DAnimation.Qt3DAnimation.QSkeletonMapping(parent:PySide2.Qt3DCore.Qt3DCore.QNode=nullptr)",
    "PySide2.Qt3DAnimation.Qt3DAnimation.QSkeletonMapping.setSkeleton(skeleton:PySide2.Qt3DCore.Qt3DCore.QAbstractSkeleton)",
    "PySide2.Qt3DAnimation.Qt3DAnimation.QSkeletonMapping.skeleton()->PySide2.Qt3DCore.Qt3DCore.QAbstractSkeleton",
    nullptr}; // Sentinel

void init_Qt3DAnimation_QSkeletonMapping(PyObject *enclosingClass)
{
    _Sbk_Qt3DAnimation_QSkeletonMapping_Type = Shiboken::ObjectType::introduceWrapperType(
        enclosingClass,
        "QSkeletonMapping",
        "Qt3DAnimation::QSkeletonMapping*",
        &Sbk_Qt3DAnimation_QSkeletonMapping_spec,
        Qt3DAnimation_QSkeletonMapping_SignatureStrings,
        &Shiboken::callCppDestructor< ::Qt3DAnimation::QSkeletonMapping >,
        0,
        0,
        Shiboken::ObjectType::WrapperFlags::InnerClass    );
    
    SbkPySide2_Qt3DAnimationTypes[SBK_QT3DANIMATION_QSKELETONMAPPING_IDX]
        = reinterpret_cast<PyTypeObject *>(Sbk_Qt3DAnimation_QSkeletonMapping_TypeF());

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(Sbk_Qt3DAnimation_QSkeletonMapping_TypeF(),
        QSkeletonMapping_PythonToCpp_QSkeletonMapping_PTR,
        is_QSkeletonMapping_PythonToCpp_QSkeletonMapping_PTR_Convertible,
        QSkeletonMapping_PTR_CppToPython_QSkeletonMapping);

    Shiboken::Conversions::registerConverterName(converter, "Qt3DAnimation::QSkeletonMapping");
    Shiboken::Conversions::registerConverterName(converter, "Qt3DAnimation::QSkeletonMapping*");
    Shiboken::Conversions::registerConverterName(converter, "Qt3DAnimation::QSkeletonMapping&");
    Shiboken::Conversions::registerConverterName(converter, "QSkeletonMapping");
    Shiboken::Conversions::registerConverterName(converter, "QSkeletonMapping*");
    Shiboken::Conversions::registerConverterName(converter, "QSkeletonMapping&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::Qt3DAnimation::QSkeletonMapping).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(::QSkeletonMappingWrapper).name());


    PySide::Signal::registerSignals(Sbk_Qt3DAnimation_QSkeletonMapping_TypeF(), &::Qt3DAnimation::QSkeletonMapping::staticMetaObject);

}
