/****************************************************************************
**
** Copyright (C) 2016 The Qt Company Ltd.
** Contact: https://www.qt.io/licensing/
**
** This file is part of Qt for Python.
**
** $QT_BEGIN_LICENSE:LGPL$
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 3 as published by the Free Software
** Foundation and appearing in the file LICENSE.LGPL3 included in the
** packaging of this file. Please review the following information to
** ensure the GNU Lesser General Public License version 3 requirements
** will be met: https://www.gnu.org/licenses/lgpl-3.0.html.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 2.0 or (at your option) the GNU General
** Public license version 3 or any later version approved by the KDE Free
** Qt Foundation. The licenses are as published by the Free Software
** Foundation and appearing in the file LICENSE.GPL2 and LICENSE.GPL3
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-2.0.html and
** https://www.gnu.org/licenses/gpl-3.0.html.
**
** $QT_END_LICENSE$
**
****************************************************************************/

//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QDebug>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <destroylistener.h>
#include <qapp_macro.h>
#include <typeinfo>

// module include
#include "pyside2_qtgui_python.h"

// main header
#include "qtexttablecellformat_wrapper.h"

// inner classes

// Extra includes
#include <QMap>
#include <QVector>
#include <QtCore/qobject.h>
#include <QtGui/qbrush.h>
#include <QtGui/qcolor.h>
#include <QtGui/qfont.h>
#include <QtGui/qpen.h>
#include <QtGui/qtextformat.h>


#include <cctype>
#include <cstring>

QT_WARNING_DISABLE_DEPRECATED



template <class T>
static const char *typeNameOf(const T &t)
{
    const char *typeName =  typeid(t).name();
    auto size = std::strlen(typeName);
#if defined(Q_CC_MSVC) // MSVC: "class QPaintDevice * __ptr64"
    if (auto lastStar = strchr(typeName, '*')) {
        // MSVC: "class QPaintDevice * __ptr64"
        while (*--lastStar == ' ') {
        }
        size = lastStar - typeName + 1;
    }
#else // g++, Clang: "QPaintDevice *" -> "P12QPaintDevice"
    if (size > 2 && typeName[0] == 'P' && std::isdigit(typeName[1])) {
        ++typeName;
        --size;
    }
#endif
    char *result = new char[size + 1];
    result[size] = '\0';
    memcpy(result, typeName, size);
    return result;
}


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QTextTableCellFormat_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SbkObject *sbkSelf = reinterpret_cast<SbkObject *>(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QTextTableCellFormat >()))
        return -1;

    ::QTextTableCellFormat *cptr{};
    int overloadId = -1;
    PythonToCppFunc pythonToCpp[] = { nullptr };
    SBK_UNUSED(pythonToCpp)
    int numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "QTextTableCellFormat", 0, 1, &(pyArgs[0])))
        return -1;


    // Overloaded function decisor
    // 0: QTextTableCellFormat::QTextTableCellFormat()
    // 1: QTextTableCellFormat::QTextTableCellFormat(QTextFormat)
    // 2: QTextTableCellFormat::QTextTableCellFormat(QTextTableCellFormat)
    if (numArgs == 0) {
        overloadId = 0; // QTextTableCellFormat()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::isPythonToCppReferenceConvertible(reinterpret_cast<SbkObjectType *>(SbkPySide2_QtGuiTypes[SBK_QTEXTTABLECELLFORMAT_IDX]), (pyArgs[0])))) {
        overloadId = 2; // QTextTableCellFormat(QTextTableCellFormat)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::isPythonToCppReferenceConvertible(reinterpret_cast<SbkObjectType *>(SbkPySide2_QtGuiTypes[SBK_QTEXTFORMAT_IDX]), (pyArgs[0])))) {
        overloadId = 1; // QTextTableCellFormat(QTextFormat)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextTableCellFormat_Init_TypeError;

    // Call function/method
    switch (overloadId) {
        case 0: // QTextTableCellFormat()
        {

            if (!PyErr_Occurred()) {
                // QTextTableCellFormat()
                PyThreadState *_save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cptr = new ::QTextTableCellFormat();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
        case 1: // QTextTableCellFormat(const QTextFormat & fmt)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QTextFormat cppArg0_local;
            ::QTextFormat *cppArg0 = &cppArg0_local;
            if (Shiboken::Conversions::isImplicitConversion(reinterpret_cast<SbkObjectType *>(SbkPySide2_QtGuiTypes[SBK_QTEXTFORMAT_IDX]), pythonToCpp[0]))
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (!PyErr_Occurred()) {
                // QTextTableCellFormat(QTextFormat)
                PyThreadState *_save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cptr = new ::QTextTableCellFormat(*cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
        case 2: // QTextTableCellFormat(const QTextTableCellFormat & QTextTableCellFormat)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QTextTableCellFormat cppArg0_local;
            ::QTextTableCellFormat *cppArg0 = &cppArg0_local;
            if (Shiboken::Conversions::isImplicitConversion(reinterpret_cast<SbkObjectType *>(SbkPySide2_QtGuiTypes[SBK_QTEXTTABLECELLFORMAT_IDX]), pythonToCpp[0]))
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (!PyErr_Occurred()) {
                // QTextTableCellFormat(QTextTableCellFormat)
                PyThreadState *_save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cptr = new ::QTextTableCellFormat(*cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QTextTableCellFormat >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto Sbk_QTextTableCellFormat_Init_TypeError;

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    Sbk_QTextTableCellFormat_Init_TypeError:
        Shiboken::setErrorAboutWrongArguments(args, "PySide2.QtGui.QTextTableCellFormat");
        return -1;
}

static PyObject *Sbk_QTextTableCellFormatFunc_bottomPadding(PyObject *self)
{
    ::QTextTableCellFormat *cppSelf = nullptr;
    SBK_UNUSED(cppSelf)
    if (!Shiboken::Object::isValid(self))
        return {};
    cppSelf = reinterpret_cast< ::QTextTableCellFormat *>(Shiboken::Conversions::cppPointer(SbkPySide2_QtGuiTypes[SBK_QTEXTTABLECELLFORMAT_IDX], reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};

    // Call function/method
    {

        if (!PyErr_Occurred()) {
            // bottomPadding()const
            qreal cppResult = const_cast<const ::QTextTableCellFormat *>(cppSelf)->bottomPadding();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), &cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextTableCellFormatFunc_isValid(PyObject *self)
{
    ::QTextTableCellFormat *cppSelf = nullptr;
    SBK_UNUSED(cppSelf)
    if (!Shiboken::Object::isValid(self))
        return {};
    cppSelf = reinterpret_cast< ::QTextTableCellFormat *>(Shiboken::Conversions::cppPointer(SbkPySide2_QtGuiTypes[SBK_QTEXTTABLECELLFORMAT_IDX], reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};

    // Call function/method
    {

        if (!PyErr_Occurred()) {
            // isValid()const
            bool cppResult = const_cast<const ::QTextTableCellFormat *>(cppSelf)->isValid();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextTableCellFormatFunc_leftPadding(PyObject *self)
{
    ::QTextTableCellFormat *cppSelf = nullptr;
    SBK_UNUSED(cppSelf)
    if (!Shiboken::Object::isValid(self))
        return {};
    cppSelf = reinterpret_cast< ::QTextTableCellFormat *>(Shiboken::Conversions::cppPointer(SbkPySide2_QtGuiTypes[SBK_QTEXTTABLECELLFORMAT_IDX], reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};

    // Call function/method
    {

        if (!PyErr_Occurred()) {
            // leftPadding()const
            qreal cppResult = const_cast<const ::QTextTableCellFormat *>(cppSelf)->leftPadding();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), &cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextTableCellFormatFunc_rightPadding(PyObject *self)
{
    ::QTextTableCellFormat *cppSelf = nullptr;
    SBK_UNUSED(cppSelf)
    if (!Shiboken::Object::isValid(self))
        return {};
    cppSelf = reinterpret_cast< ::QTextTableCellFormat *>(Shiboken::Conversions::cppPointer(SbkPySide2_QtGuiTypes[SBK_QTEXTTABLECELLFORMAT_IDX], reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};

    // Call function/method
    {

        if (!PyErr_Occurred()) {
            // rightPadding()const
            qreal cppResult = const_cast<const ::QTextTableCellFormat *>(cppSelf)->rightPadding();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), &cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextTableCellFormatFunc_setBottomPadding(PyObject *self, PyObject *pyArg)
{
    ::QTextTableCellFormat *cppSelf = nullptr;
    SBK_UNUSED(cppSelf)
    if (!Shiboken::Object::isValid(self))
        return {};
    cppSelf = reinterpret_cast< ::QTextTableCellFormat *>(Shiboken::Conversions::cppPointer(SbkPySide2_QtGuiTypes[SBK_QTEXTTABLECELLFORMAT_IDX], reinterpret_cast<SbkObject *>(self)));
    int overloadId = -1;
    PythonToCppFunc pythonToCpp{};
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QTextTableCellFormat::setBottomPadding(qreal)
    if ((pythonToCpp = Shiboken::Conversions::isPythonToCppConvertible(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArg)))) {
        overloadId = 0; // setBottomPadding(qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextTableCellFormatFunc_setBottomPadding_TypeError;

    // Call function/method
    {
        qreal cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (!PyErr_Occurred()) {
            // setBottomPadding(qreal)
            PyThreadState *_save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cppSelf->setBottomPadding(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return {};
    }
    Py_RETURN_NONE;

    Sbk_QTextTableCellFormatFunc_setBottomPadding_TypeError:
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide2.QtGui.QTextTableCellFormat.setBottomPadding");
        return {};
}

static PyObject *Sbk_QTextTableCellFormatFunc_setLeftPadding(PyObject *self, PyObject *pyArg)
{
    ::QTextTableCellFormat *cppSelf = nullptr;
    SBK_UNUSED(cppSelf)
    if (!Shiboken::Object::isValid(self))
        return {};
    cppSelf = reinterpret_cast< ::QTextTableCellFormat *>(Shiboken::Conversions::cppPointer(SbkPySide2_QtGuiTypes[SBK_QTEXTTABLECELLFORMAT_IDX], reinterpret_cast<SbkObject *>(self)));
    int overloadId = -1;
    PythonToCppFunc pythonToCpp{};
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QTextTableCellFormat::setLeftPadding(qreal)
    if ((pythonToCpp = Shiboken::Conversions::isPythonToCppConvertible(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArg)))) {
        overloadId = 0; // setLeftPadding(qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextTableCellFormatFunc_setLeftPadding_TypeError;

    // Call function/method
    {
        qreal cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (!PyErr_Occurred()) {
            // setLeftPadding(qreal)
            PyThreadState *_save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cppSelf->setLeftPadding(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return {};
    }
    Py_RETURN_NONE;

    Sbk_QTextTableCellFormatFunc_setLeftPadding_TypeError:
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide2.QtGui.QTextTableCellFormat.setLeftPadding");
        return {};
}

static PyObject *Sbk_QTextTableCellFormatFunc_setPadding(PyObject *self, PyObject *pyArg)
{
    ::QTextTableCellFormat *cppSelf = nullptr;
    SBK_UNUSED(cppSelf)
    if (!Shiboken::Object::isValid(self))
        return {};
    cppSelf = reinterpret_cast< ::QTextTableCellFormat *>(Shiboken::Conversions::cppPointer(SbkPySide2_QtGuiTypes[SBK_QTEXTTABLECELLFORMAT_IDX], reinterpret_cast<SbkObject *>(self)));
    int overloadId = -1;
    PythonToCppFunc pythonToCpp{};
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QTextTableCellFormat::setPadding(qreal)
    if ((pythonToCpp = Shiboken::Conversions::isPythonToCppConvertible(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArg)))) {
        overloadId = 0; // setPadding(qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextTableCellFormatFunc_setPadding_TypeError;

    // Call function/method
    {
        qreal cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (!PyErr_Occurred()) {
            // setPadding(qreal)
            PyThreadState *_save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cppSelf->setPadding(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return {};
    }
    Py_RETURN_NONE;

    Sbk_QTextTableCellFormatFunc_setPadding_TypeError:
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide2.QtGui.QTextTableCellFormat.setPadding");
        return {};
}

static PyObject *Sbk_QTextTableCellFormatFunc_setRightPadding(PyObject *self, PyObject *pyArg)
{
    ::QTextTableCellFormat *cppSelf = nullptr;
    SBK_UNUSED(cppSelf)
    if (!Shiboken::Object::isValid(self))
        return {};
    cppSelf = reinterpret_cast< ::QTextTableCellFormat *>(Shiboken::Conversions::cppPointer(SbkPySide2_QtGuiTypes[SBK_QTEXTTABLECELLFORMAT_IDX], reinterpret_cast<SbkObject *>(self)));
    int overloadId = -1;
    PythonToCppFunc pythonToCpp{};
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QTextTableCellFormat::setRightPadding(qreal)
    if ((pythonToCpp = Shiboken::Conversions::isPythonToCppConvertible(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArg)))) {
        overloadId = 0; // setRightPadding(qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextTableCellFormatFunc_setRightPadding_TypeError;

    // Call function/method
    {
        qreal cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (!PyErr_Occurred()) {
            // setRightPadding(qreal)
            PyThreadState *_save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cppSelf->setRightPadding(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return {};
    }
    Py_RETURN_NONE;

    Sbk_QTextTableCellFormatFunc_setRightPadding_TypeError:
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide2.QtGui.QTextTableCellFormat.setRightPadding");
        return {};
}

static PyObject *Sbk_QTextTableCellFormatFunc_setTopPadding(PyObject *self, PyObject *pyArg)
{
    ::QTextTableCellFormat *cppSelf = nullptr;
    SBK_UNUSED(cppSelf)
    if (!Shiboken::Object::isValid(self))
        return {};
    cppSelf = reinterpret_cast< ::QTextTableCellFormat *>(Shiboken::Conversions::cppPointer(SbkPySide2_QtGuiTypes[SBK_QTEXTTABLECELLFORMAT_IDX], reinterpret_cast<SbkObject *>(self)));
    int overloadId = -1;
    PythonToCppFunc pythonToCpp{};
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QTextTableCellFormat::setTopPadding(qreal)
    if ((pythonToCpp = Shiboken::Conversions::isPythonToCppConvertible(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArg)))) {
        overloadId = 0; // setTopPadding(qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextTableCellFormatFunc_setTopPadding_TypeError;

    // Call function/method
    {
        qreal cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (!PyErr_Occurred()) {
            // setTopPadding(qreal)
            PyThreadState *_save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cppSelf->setTopPadding(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return {};
    }
    Py_RETURN_NONE;

    Sbk_QTextTableCellFormatFunc_setTopPadding_TypeError:
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide2.QtGui.QTextTableCellFormat.setTopPadding");
        return {};
}

static PyObject *Sbk_QTextTableCellFormatFunc_topPadding(PyObject *self)
{
    ::QTextTableCellFormat *cppSelf = nullptr;
    SBK_UNUSED(cppSelf)
    if (!Shiboken::Object::isValid(self))
        return {};
    cppSelf = reinterpret_cast< ::QTextTableCellFormat *>(Shiboken::Conversions::cppPointer(SbkPySide2_QtGuiTypes[SBK_QTEXTTABLECELLFORMAT_IDX], reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};

    // Call function/method
    {

        if (!PyErr_Occurred()) {
            // topPadding()const
            qreal cppResult = const_cast<const ::QTextTableCellFormat *>(cppSelf)->topPadding();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), &cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextTableCellFormat___copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    ::QTextTableCellFormat &cppSelf =  *reinterpret_cast< ::QTextTableCellFormat *>(Shiboken::Conversions::cppPointer(SbkPySide2_QtGuiTypes[SBK_QTEXTTABLECELLFORMAT_IDX], reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(reinterpret_cast<SbkObjectType *>(SbkPySide2_QtGuiTypes[SBK_QTEXTTABLECELLFORMAT_IDX]), &cppSelf);
    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyMethodDef Sbk_QTextTableCellFormat_methods[] = {
    {"bottomPadding", reinterpret_cast<PyCFunction>(Sbk_QTextTableCellFormatFunc_bottomPadding), METH_NOARGS},
    {"isValid", reinterpret_cast<PyCFunction>(Sbk_QTextTableCellFormatFunc_isValid), METH_NOARGS},
    {"leftPadding", reinterpret_cast<PyCFunction>(Sbk_QTextTableCellFormatFunc_leftPadding), METH_NOARGS},
    {"rightPadding", reinterpret_cast<PyCFunction>(Sbk_QTextTableCellFormatFunc_rightPadding), METH_NOARGS},
    {"setBottomPadding", reinterpret_cast<PyCFunction>(Sbk_QTextTableCellFormatFunc_setBottomPadding), METH_O},
    {"setLeftPadding", reinterpret_cast<PyCFunction>(Sbk_QTextTableCellFormatFunc_setLeftPadding), METH_O},
    {"setPadding", reinterpret_cast<PyCFunction>(Sbk_QTextTableCellFormatFunc_setPadding), METH_O},
    {"setRightPadding", reinterpret_cast<PyCFunction>(Sbk_QTextTableCellFormatFunc_setRightPadding), METH_O},
    {"setTopPadding", reinterpret_cast<PyCFunction>(Sbk_QTextTableCellFormatFunc_setTopPadding), METH_O},
    {"topPadding", reinterpret_cast<PyCFunction>(Sbk_QTextTableCellFormatFunc_topPadding), METH_NOARGS},

    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QTextTableCellFormat___copy__), METH_NOARGS},
    {nullptr, nullptr} // Sentinel
};

} // extern "C"

static int Sbk_QTextTableCellFormat_traverse(PyObject *self, visitproc visit, void *arg)
{
    return reinterpret_cast<PyTypeObject *>(SbkObject_TypeF())->tp_traverse(self, visit, arg);
}
static int Sbk_QTextTableCellFormat_clear(PyObject *self)
{
    return reinterpret_cast<PyTypeObject *>(SbkObject_TypeF())->tp_clear(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType *_Sbk_QTextTableCellFormat_Type = nullptr;
static SbkObjectType *Sbk_QTextTableCellFormat_TypeF(void)
{
    return _Sbk_QTextTableCellFormat_Type;
}

static PyType_Slot Sbk_QTextTableCellFormat_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_repr,        nullptr},
    {Py_tp_hash,        nullptr},
    {Py_tp_call,        nullptr},
    {Py_tp_str,         nullptr},
    {Py_tp_getattro,    nullptr},
    {Py_tp_setattro,    nullptr},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QTextTableCellFormat_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QTextTableCellFormat_clear)},
    {Py_tp_richcompare, nullptr},
    {Py_tp_iter,        nullptr},
    {Py_tp_iternext,    nullptr},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QTextTableCellFormat_methods)},
    {Py_tp_getset,      nullptr},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QTextTableCellFormat_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObjectTpNew)},
    {0, nullptr}
};
static PyType_Spec Sbk_QTextTableCellFormat_spec = {
    "PySide2.QtGui.QTextTableCellFormat",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_GC,
    Sbk_QTextTableCellFormat_slots
};

} //extern "C"


// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QTextTableCellFormat_PythonToCpp_QTextTableCellFormat_PTR(PyObject *pyIn, void *cppOut) {
    Shiboken::Conversions::pythonToCppPointer(Sbk_QTextTableCellFormat_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QTextTableCellFormat_PythonToCpp_QTextTableCellFormat_PTR_Convertible(PyObject *pyIn) {
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, reinterpret_cast<PyTypeObject *>(Sbk_QTextTableCellFormat_TypeF())))
        return QTextTableCellFormat_PythonToCpp_QTextTableCellFormat_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QTextTableCellFormat_PTR_CppToPython_QTextTableCellFormat(const void *cppIn) {
    auto pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    bool changedTypeName = false;
    auto tCppIn = reinterpret_cast<const ::QTextTableCellFormat *>(cppIn);
    const char *typeName = typeid(*tCppIn).name();
    auto sbkType = Shiboken::ObjectType::typeForTypeName(typeName);
    if (sbkType && Shiboken::ObjectType::hasSpecialCastFunction(sbkType)) {
        typeName = typeNameOf(tCppIn);
        changedTypeName = true;
     }
    PyObject *result = Shiboken::Object::newObject(Sbk_QTextTableCellFormat_TypeF(), const_cast<void *>(cppIn), false, /* exactType */ changedTypeName, typeName);
    if (changedTypeName)
        delete [] typeName;
    return result;
}

// C++ to Python copy conversion.
static PyObject *QTextTableCellFormat_COPY_CppToPython_QTextTableCellFormat(const void *cppIn) {
    return Shiboken::Object::newObject(Sbk_QTextTableCellFormat_TypeF(), new ::QTextTableCellFormat(*reinterpret_cast<const ::QTextTableCellFormat *>(cppIn)), true, true);
}

// Python to C++ copy conversion.
static void QTextTableCellFormat_PythonToCpp_QTextTableCellFormat_COPY(PyObject *pyIn, void *cppOut) {
    *reinterpret_cast<::QTextTableCellFormat *>(cppOut) = *reinterpret_cast< ::QTextTableCellFormat *>(Shiboken::Conversions::cppPointer(SbkPySide2_QtGuiTypes[SBK_QTEXTTABLECELLFORMAT_IDX], reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_QTextTableCellFormat_PythonToCpp_QTextTableCellFormat_COPY_Convertible(PyObject *pyIn) {
    if (PyObject_TypeCheck(pyIn, reinterpret_cast<PyTypeObject *>(Sbk_QTextTableCellFormat_TypeF())))
        return QTextTableCellFormat_PythonToCpp_QTextTableCellFormat_COPY;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
static const char *QTextTableCellFormat_SignatureStrings[] = {
    "2:PySide2.QtGui.QTextTableCellFormat()",
    "1:PySide2.QtGui.QTextTableCellFormat(fmt:PySide2.QtGui.QTextFormat)",
    "0:PySide2.QtGui.QTextTableCellFormat(QTextTableCellFormat:PySide2.QtGui.QTextTableCellFormat)",
    "PySide2.QtGui.QTextTableCellFormat.bottomPadding()->double",
    "PySide2.QtGui.QTextTableCellFormat.isValid()->bool",
    "PySide2.QtGui.QTextTableCellFormat.leftPadding()->double",
    "PySide2.QtGui.QTextTableCellFormat.rightPadding()->double",
    "PySide2.QtGui.QTextTableCellFormat.setBottomPadding(padding:double)",
    "PySide2.QtGui.QTextTableCellFormat.setLeftPadding(padding:double)",
    "PySide2.QtGui.QTextTableCellFormat.setPadding(padding:double)",
    "PySide2.QtGui.QTextTableCellFormat.setRightPadding(padding:double)",
    "PySide2.QtGui.QTextTableCellFormat.setTopPadding(padding:double)",
    "PySide2.QtGui.QTextTableCellFormat.topPadding()->double",
    "PySide2.QtGui.QTextTableCellFormat.__copy__()",
    nullptr}; // Sentinel

void init_QTextTableCellFormat(PyObject *module)
{
    _Sbk_QTextTableCellFormat_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QTextTableCellFormat",
        "QTextTableCellFormat",
        &Sbk_QTextTableCellFormat_spec,
        QTextTableCellFormat_SignatureStrings,
        &Shiboken::callCppDestructor< ::QTextTableCellFormat >,
        reinterpret_cast<SbkObjectType *>(SbkPySide2_QtGuiTypes[SBK_QTEXTCHARFORMAT_IDX]),
        0,
        0    );
    
    SbkPySide2_QtGuiTypes[SBK_QTEXTTABLECELLFORMAT_IDX]
        = reinterpret_cast<PyTypeObject *>(Sbk_QTextTableCellFormat_TypeF());

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(Sbk_QTextTableCellFormat_TypeF(),
        QTextTableCellFormat_PythonToCpp_QTextTableCellFormat_PTR,
        is_QTextTableCellFormat_PythonToCpp_QTextTableCellFormat_PTR_Convertible,
        QTextTableCellFormat_PTR_CppToPython_QTextTableCellFormat,
        QTextTableCellFormat_COPY_CppToPython_QTextTableCellFormat);

    Shiboken::Conversions::registerConverterName(converter, "QTextTableCellFormat");
    Shiboken::Conversions::registerConverterName(converter, "QTextTableCellFormat*");
    Shiboken::Conversions::registerConverterName(converter, "QTextTableCellFormat&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QTextTableCellFormat).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QTextTableCellFormat_PythonToCpp_QTextTableCellFormat_COPY,
        is_QTextTableCellFormat_PythonToCpp_QTextTableCellFormat_COPY_Convertible);


    qRegisterMetaType< ::QTextTableCellFormat >("QTextTableCellFormat");
}
