/****************************************************************************
**
** Copyright (C) 2016 The Qt Company Ltd.
** Contact: https://www.qt.io/licensing/
**
** This file is part of Qt for Python.
**
** $QT_BEGIN_LICENSE:LGPL$
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 3 as published by the Free Software
** Foundation and appearing in the file LICENSE.LGPL3 included in the
** packaging of this file. Please review the following information to
** ensure the GNU Lesser General Public License version 3 requirements
** will be met: https://www.gnu.org/licenses/lgpl-3.0.html.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 2.0 or (at your option) the GNU General
** Public license version 3 or any later version approved by the KDE Free
** Qt Foundation. The licenses are as published by the Free Software
** Foundation and appearing in the file LICENSE.GPL2 and LICENSE.GPL3
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-2.0.html and
** https://www.gnu.org/licenses/gpl-3.0.html.
**
** $QT_END_LICENSE$
**
****************************************************************************/

//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QDebug>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <destroylistener.h>
#include <qapp_macro.h>
#include <typeinfo>
#include <signalmanager.h>
#include <pysidemetafunction.h>

// module include
#include "pyside2_qtquick_python.h"

// main header
#include "qsgabstractrenderer_wrapper.h"

// inner classes

// Extra includes
#include <QList>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qobject.h>
#include <QtCore/qrect.h>
#include <QtCore/qsize.h>
#include <QtCore/qthread.h>
#include <QtGui/qcolor.h>
#include <QtGui/qmatrix4x4.h>
#include <QtQuick/qsgnode.h>
#include <qobjectdefs.h>


#include <cctype>
#include <cstring>

QT_WARNING_DISABLE_DEPRECATED



template <class T>
static const char *typeNameOf(const T &t)
{
    const char *typeName =  typeid(t).name();
    auto size = std::strlen(typeName);
#if defined(Q_CC_MSVC) // MSVC: "class QPaintDevice * __ptr64"
    if (auto lastStar = strchr(typeName, '*')) {
        // MSVC: "class QPaintDevice * __ptr64"
        while (*--lastStar == ' ') {
        }
        size = lastStar - typeName + 1;
    }
#else // g++, Clang: "QPaintDevice *" -> "P12QPaintDevice"
    if (size > 2 && typeName[0] == 'P' && std::isdigit(typeName[1])) {
        ++typeName;
        --size;
    }
#endif
    char *result = new char[size + 1];
    result[size] = '\0';
    memcpy(result, typeName, size);
    return result;
}

// Native ---------------------------------------------------------

QSGAbstractRendererWrapper::QSGAbstractRendererWrapper(QObject * parent) : QSGAbstractRenderer(parent)
{
    // ... middle
}

void QSGAbstractRendererWrapper::childEvent(QChildEvent * event)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return;
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, "childEvent"));
    if (pyOverride.isNull()) {
        gil.release();
        this->::QObject::childEvent(event);
        return;
    }

    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(reinterpret_cast<SbkObjectType *>(SbkPySide2_QtCoreTypes[SBK_QCHILDEVENT_IDX]), event)
    ));
    bool invalidateArg1 = PyTuple_GET_ITEM(pyArgs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return;
    }
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyArgs, 0));
}

void QSGAbstractRendererWrapper::connectNotify(const QMetaMethod & signal)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return;
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, "connectNotify"));
    if (pyOverride.isNull()) {
        gil.release();
        this->::QObject::connectNotify(signal);
        return;
    }

    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(reinterpret_cast<SbkObjectType *>(SbkPySide2_QtCoreTypes[SBK_QMETAMETHOD_IDX]), &signal)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return;
    }
}

void QSGAbstractRendererWrapper::customEvent(QEvent * event)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return;
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, "customEvent"));
    if (pyOverride.isNull()) {
        gil.release();
        this->::QObject::customEvent(event);
        return;
    }

    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(reinterpret_cast<SbkObjectType *>(SbkPySide2_QtCoreTypes[SBK_QEVENT_IDX]), event)
    ));
    bool invalidateArg1 = PyTuple_GET_ITEM(pyArgs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return;
    }
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyArgs, 0));
}

void QSGAbstractRendererWrapper::disconnectNotify(const QMetaMethod & signal)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return;
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, "disconnectNotify"));
    if (pyOverride.isNull()) {
        gil.release();
        this->::QObject::disconnectNotify(signal);
        return;
    }

    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(reinterpret_cast<SbkObjectType *>(SbkPySide2_QtCoreTypes[SBK_QMETAMETHOD_IDX]), &signal)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return;
    }
}

bool QSGAbstractRendererWrapper::event(QEvent * event)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return false;
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, "event"));
    if (pyOverride.isNull()) {
        gil.release();
        return this->::QObject::event(event);
    }

    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(reinterpret_cast<SbkObjectType *>(SbkPySide2_QtCoreTypes[SBK_QEVENT_IDX]), event)
    ));
    bool invalidateArg1 = PyTuple_GET_ITEM(pyArgs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return false;
    }
    // Check return type
    PythonToCppFunc pythonToCpp = Shiboken::Conversions::isPythonToCppConvertible(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::warning(PyExc_RuntimeWarning, 2, "Invalid return value in function %s, expected %s, got %s.", "QSGAbstractRenderer.event", "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyArgs, 0));
    return cppResult;
}

bool QSGAbstractRendererWrapper::eventFilter(QObject * watched, QEvent * event)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return false;
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, "eventFilter"));
    if (pyOverride.isNull()) {
        gil.release();
        return this->::QObject::eventFilter(watched, event);
    }

    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NN)",
        Shiboken::Conversions::pointerToPython(reinterpret_cast<SbkObjectType *>(SbkPySide2_QtCoreTypes[SBK_QOBJECT_IDX]), watched),
        Shiboken::Conversions::pointerToPython(reinterpret_cast<SbkObjectType *>(SbkPySide2_QtCoreTypes[SBK_QEVENT_IDX]), event)
    ));
    bool invalidateArg2 = PyTuple_GET_ITEM(pyArgs, 1)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return false;
    }
    // Check return type
    PythonToCppFunc pythonToCpp = Shiboken::Conversions::isPythonToCppConvertible(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::warning(PyExc_RuntimeWarning, 2, "Invalid return value in function %s, expected %s, got %s.", "QSGAbstractRenderer.eventFilter", "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    if (invalidateArg2)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyArgs, 1));
    return cppResult;
}

void QSGAbstractRendererWrapper::nodeChanged(QSGNode * node, QFlags<QSGNode::DirtyStateBit> state)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return;
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, "nodeChanged"));
    if (pyOverride.isNull()) {
        PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'QSGAbstractRenderer.nodeChanged()' not implemented.");
        return;
    }

    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NN)",
        Shiboken::Conversions::pointerToPython(reinterpret_cast<SbkObjectType *>(SbkPySide2_QtQuickTypes[SBK_QSGNODE_IDX]), node),
        Shiboken::Conversions::copyToPython(*PepType_SGTP(SbkPySide2_QtQuickTypes[SBK_QFLAGS_QSGNODE_DIRTYSTATEBIT_IDX])->converter, &state)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return;
    }
}

void QSGAbstractRendererWrapper::renderScene(uint fboId)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return;
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, "renderScene"));
    if (pyOverride.isNull()) {
        PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'QSGAbstractRenderer.renderScene()' not implemented.");
        return;
    }

    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(I)",
        fboId
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return;
    }
}

void QSGAbstractRendererWrapper::timerEvent(QTimerEvent * event)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return;
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, "timerEvent"));
    if (pyOverride.isNull()) {
        gil.release();
        this->::QObject::timerEvent(event);
        return;
    }

    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(reinterpret_cast<SbkObjectType *>(SbkPySide2_QtCoreTypes[SBK_QTIMEREVENT_IDX]), event)
    ));
    bool invalidateArg1 = PyTuple_GET_ITEM(pyArgs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return;
    }
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyArgs, 0));
}

const QMetaObject *QSGAbstractRendererWrapper::metaObject() const
{
    if (QObject::d_ptr->metaObject)
        return QObject::d_ptr->dynamicMetaObject();
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf == nullptr)
        return QSGAbstractRenderer::metaObject();
    return PySide::SignalManager::retrieveMetaObject(reinterpret_cast<PyObject *>(pySelf));
}

int QSGAbstractRendererWrapper::qt_metacall(QMetaObject::Call call, int id, void **args)
{
    int result = QSGAbstractRenderer::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

void *QSGAbstractRendererWrapper::qt_metacast(const char *_clname)
{
        if (!_clname) return {};
        SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
        if (pySelf && PySide::inherits(Py_TYPE(pySelf), _clname))
                return static_cast<void *>(const_cast< QSGAbstractRendererWrapper *>(this));
        return QSGAbstractRenderer::qt_metacast(_clname);
}

QSGAbstractRendererWrapper::~QSGAbstractRendererWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QSGAbstractRenderer_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    const char *argNames[] = {"parent"};
    const QMetaObject *metaObject;
    SbkObject *sbkSelf = reinterpret_cast<SbkObject *>(self);
    SbkObjectType *type = reinterpret_cast<SbkObjectType *>(self->ob_type);
    SbkObjectType *myType = reinterpret_cast<SbkObjectType *>(SbkPySide2_QtQuickTypes[SBK_QSGABSTRACTRENDERER_IDX]);
    if (type == myType) {
        PyErr_SetString(PyExc_NotImplementedError,
            "'QSGAbstractRenderer' represents a C++ abstract class and cannot be instantiated");
        return -1;
    }

    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QSGAbstractRenderer >()))
        return -1;

    ::QSGAbstractRendererWrapper *cptr{};
    int overloadId = -1;
    PythonToCppFunc pythonToCpp[] = { nullptr };
    SBK_UNUSED(pythonToCpp)
    int numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {0};

    // invalid argument lengths


    if (!PyArg_ParseTuple(args, "|O:QSGAbstractRenderer", &(pyArgs[0])))
        return -1;


    // Overloaded function decisor
    // 0: QSGAbstractRenderer::QSGAbstractRenderer(QObject*)
    if (numArgs == 0) {
        overloadId = 0; // QSGAbstractRenderer(QObject*)
    } else if ((pythonToCpp[0] = Shiboken::Conversions::isPythonToCppPointerConvertible(reinterpret_cast<SbkObjectType *>(SbkPySide2_QtCoreTypes[SBK_QOBJECT_IDX]), (pyArgs[0])))) {
        overloadId = 0; // QSGAbstractRenderer(QObject*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QSGAbstractRenderer_Init_TypeError;

    // Call function/method
    {
        if (kwds) {
            PyObject *keyName = nullptr;
            PyObject *value = nullptr;
            keyName = Py_BuildValue("s","parent");
            if (PyDict_Contains(kwds, keyName)) {
            value = PyDict_GetItemString(kwds, "parent");
            if (value && pyArgs[0]) {
                PyErr_SetString(PyExc_TypeError, "PySide2.QtQuick.QSGAbstractRenderer(): got multiple values for keyword argument 'parent'.");
                return -1;
                        } else if (value) {
                pyArgs[0] = value;
                if (!(pythonToCpp[0] = Shiboken::Conversions::isPythonToCppPointerConvertible(reinterpret_cast<SbkObjectType *>(SbkPySide2_QtCoreTypes[SBK_QOBJECT_IDX]), (pyArgs[0]))))
                    goto Sbk_QSGAbstractRenderer_Init_TypeError;
            }
}
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return -1;
        ::QObject *cppArg0 = nullptr;
        if (pythonToCpp[0]) pythonToCpp[0](pyArgs[0], &cppArg0);

        if (!PyErr_Occurred()) {
            // QSGAbstractRenderer(QObject*)
            void *addr = PySide::nextQObjectMemoryAddr();
            PyThreadState *_save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            if (addr) {
                cptr = new (addr) ::QSGAbstractRendererWrapper(cppArg0);
                PySide::setNextQObjectMemoryAddr(0);
            } else {
                cptr = new ::QSGAbstractRendererWrapper(cppArg0);
            }

            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            Shiboken::Object::setParent(pyArgs[0], self);
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QSGAbstractRenderer >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto Sbk_QSGAbstractRenderer_Init_TypeError;

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);

    // QObject setup
    PySide::Signal::updateSourceObject(self);
    metaObject = cptr->metaObject(); // <- init python qt properties
    if (kwds && !PySide::fillQtProperties(self, metaObject, kwds, argNames, 1))
        return -1;


    return 1;

    Sbk_QSGAbstractRenderer_Init_TypeError:
        Shiboken::setErrorAboutWrongArguments(args, "PySide2.QtQuick.QSGAbstractRenderer");
        return -1;
}

static PyObject *Sbk_QSGAbstractRendererFunc_clearColor(PyObject *self)
{
    ::QSGAbstractRenderer *cppSelf = nullptr;
    SBK_UNUSED(cppSelf)
    if (!Shiboken::Object::isValid(self))
        return {};
    cppSelf = reinterpret_cast< ::QSGAbstractRenderer *>(Shiboken::Conversions::cppPointer(SbkPySide2_QtQuickTypes[SBK_QSGABSTRACTRENDERER_IDX], reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};

    // Call function/method
    {

        if (!PyErr_Occurred()) {
            // clearColor()const
            QColor cppResult = const_cast<const ::QSGAbstractRenderer *>(cppSelf)->clearColor();
            pyResult = Shiboken::Conversions::copyToPython(reinterpret_cast<SbkObjectType *>(SbkPySide2_QtGuiTypes[SBK_QCOLOR_IDX]), &cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSGAbstractRendererFunc_clearMode(PyObject *self)
{
    ::QSGAbstractRenderer *cppSelf = nullptr;
    SBK_UNUSED(cppSelf)
    if (!Shiboken::Object::isValid(self))
        return {};
    cppSelf = reinterpret_cast< ::QSGAbstractRenderer *>(Shiboken::Conversions::cppPointer(SbkPySide2_QtQuickTypes[SBK_QSGABSTRACTRENDERER_IDX], reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};

    // Call function/method
    {

        if (!PyErr_Occurred()) {
            // clearMode()const
            QFlags<QSGAbstractRenderer::ClearModeBit> cppResult = const_cast<const ::QSGAbstractRenderer *>(cppSelf)->clearMode();
            pyResult = Shiboken::Conversions::copyToPython(*PepType_SGTP(SbkPySide2_QtQuickTypes[SBK_QFLAGS_QSGABSTRACTRENDERER_CLEARMODEBIT_IDX])->converter, &cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSGAbstractRendererFunc_deviceRect(PyObject *self)
{
    ::QSGAbstractRenderer *cppSelf = nullptr;
    SBK_UNUSED(cppSelf)
    if (!Shiboken::Object::isValid(self))
        return {};
    cppSelf = reinterpret_cast< ::QSGAbstractRenderer *>(Shiboken::Conversions::cppPointer(SbkPySide2_QtQuickTypes[SBK_QSGABSTRACTRENDERER_IDX], reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};

    // Call function/method
    {

        if (!PyErr_Occurred()) {
            // deviceRect()const
            QRect cppResult = const_cast<const ::QSGAbstractRenderer *>(cppSelf)->deviceRect();
            pyResult = Shiboken::Conversions::copyToPython(reinterpret_cast<SbkObjectType *>(SbkPySide2_QtCoreTypes[SBK_QRECT_IDX]), &cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSGAbstractRendererFunc_nodeChanged(PyObject *self, PyObject *args)
{
    ::QSGAbstractRenderer *cppSelf = nullptr;
    SBK_UNUSED(cppSelf)
    if (!Shiboken::Object::isValid(self))
        return {};
    cppSelf = reinterpret_cast< ::QSGAbstractRenderer *>(Shiboken::Conversions::cppPointer(SbkPySide2_QtQuickTypes[SBK_QSGABSTRACTRENDERER_IDX], reinterpret_cast<SbkObject *>(self)));
    int overloadId = -1;
    PythonToCppFunc pythonToCpp[] = { nullptr, nullptr };
    SBK_UNUSED(pythonToCpp)
    int numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "nodeChanged", 2, 2, &(pyArgs[0]), &(pyArgs[1])))
        return {};


    // Overloaded function decisor
    // 0: QSGAbstractRenderer::nodeChanged(QSGNode*,QFlags<QSGNode::DirtyStateBit>)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::isPythonToCppPointerConvertible(reinterpret_cast<SbkObjectType *>(SbkPySide2_QtQuickTypes[SBK_QSGNODE_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::isPythonToCppConvertible(*PepType_SGTP(SbkPySide2_QtQuickTypes[SBK_QFLAGS_QSGNODE_DIRTYSTATEBIT_IDX])->converter, (pyArgs[1])))) {
        overloadId = 0; // nodeChanged(QSGNode*,QFlags<QSGNode::DirtyStateBit>)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QSGAbstractRendererFunc_nodeChanged_TypeError;

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QSGNode *cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QFlags<QSGNode::DirtyStateBit> cppArg1 = QFlags<QSGNode::DirtyStateBit>(0);
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (!PyErr_Occurred()) {
            // nodeChanged(QSGNode*,QFlags<QSGNode::DirtyStateBit>)
            if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
                PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'QSGAbstractRenderer.nodeChanged()' not implemented.");
                return {};
            }
            PyThreadState *_save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cppSelf->nodeChanged(cppArg0, cppArg1);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return {};
    }
    Py_RETURN_NONE;

    Sbk_QSGAbstractRendererFunc_nodeChanged_TypeError:
        Shiboken::setErrorAboutWrongArguments(args, "PySide2.QtQuick.QSGAbstractRenderer.nodeChanged");
        return {};
}

static PyObject *Sbk_QSGAbstractRendererFunc_projectionMatrix(PyObject *self)
{
    ::QSGAbstractRenderer *cppSelf = nullptr;
    SBK_UNUSED(cppSelf)
    if (!Shiboken::Object::isValid(self))
        return {};
    cppSelf = reinterpret_cast< ::QSGAbstractRenderer *>(Shiboken::Conversions::cppPointer(SbkPySide2_QtQuickTypes[SBK_QSGABSTRACTRENDERER_IDX], reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};

    // Call function/method
    {

        if (!PyErr_Occurred()) {
            // projectionMatrix()const
            QMatrix4x4 cppResult = const_cast<const ::QSGAbstractRenderer *>(cppSelf)->projectionMatrix();
            pyResult = Shiboken::Conversions::copyToPython(reinterpret_cast<SbkObjectType *>(SbkPySide2_QtGuiTypes[SBK_QMATRIX4X4_IDX]), &cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSGAbstractRendererFunc_renderScene(PyObject *self, PyObject *args, PyObject *kwds)
{
    ::QSGAbstractRenderer *cppSelf = nullptr;
    SBK_UNUSED(cppSelf)
    if (!Shiboken::Object::isValid(self))
        return {};
    cppSelf = reinterpret_cast< ::QSGAbstractRenderer *>(Shiboken::Conversions::cppPointer(SbkPySide2_QtQuickTypes[SBK_QSGABSTRACTRENDERER_IDX], reinterpret_cast<SbkObject *>(self)));
    int overloadId = -1;
    PythonToCppFunc pythonToCpp[] = { nullptr };
    SBK_UNUSED(pythonToCpp)
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 1) {
        PyErr_SetString(PyExc_TypeError, "PySide2.QtQuick.QSGAbstractRenderer.renderScene(): too many arguments");
        return {};
    }

    if (!PyArg_ParseTuple(args, "|O:renderScene", &(pyArgs[0])))
        return {};


    // Overloaded function decisor
    // 0: QSGAbstractRenderer::renderScene(uint)
    if (numArgs == 0) {
        overloadId = 0; // renderScene(uint)
    } else if ((pythonToCpp[0] = Shiboken::Conversions::isPythonToCppConvertible(Shiboken::Conversions::PrimitiveTypeConverter<uint>(), (pyArgs[0])))) {
        overloadId = 0; // renderScene(uint)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QSGAbstractRendererFunc_renderScene_TypeError;

    // Call function/method
    {
        if (kwds) {
            PyObject *keyName = nullptr;
            PyObject *value = nullptr;
            keyName = Py_BuildValue("s","fboId");
            if (PyDict_Contains(kwds, keyName)) {
            value = PyDict_GetItemString(kwds, "fboId");
            if (value && pyArgs[0]) {
                PyErr_SetString(PyExc_TypeError, "PySide2.QtQuick.QSGAbstractRenderer.renderScene(): got multiple values for keyword argument 'fboId'.");
                return {};
                        } else if (value) {
                pyArgs[0] = value;
                if (!(pythonToCpp[0] = Shiboken::Conversions::isPythonToCppConvertible(Shiboken::Conversions::PrimitiveTypeConverter<uint>(), (pyArgs[0]))))
                    goto Sbk_QSGAbstractRendererFunc_renderScene_TypeError;
            }
}
        }
        uint cppArg0 = 0;
        if (pythonToCpp[0]) pythonToCpp[0](pyArgs[0], &cppArg0);

        if (!PyErr_Occurred()) {
            // renderScene(uint)
            if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
                PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'QSGAbstractRenderer.renderScene()' not implemented.");
                return {};
            }
            PyThreadState *_save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cppSelf->renderScene(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return {};
    }
    Py_RETURN_NONE;

    Sbk_QSGAbstractRendererFunc_renderScene_TypeError:
        Shiboken::setErrorAboutWrongArguments(args, "PySide2.QtQuick.QSGAbstractRenderer.renderScene");
        return {};
}

static PyObject *Sbk_QSGAbstractRendererFunc_setClearColor(PyObject *self, PyObject *pyArg)
{
    ::QSGAbstractRenderer *cppSelf = nullptr;
    SBK_UNUSED(cppSelf)
    if (!Shiboken::Object::isValid(self))
        return {};
    cppSelf = reinterpret_cast< ::QSGAbstractRenderer *>(Shiboken::Conversions::cppPointer(SbkPySide2_QtQuickTypes[SBK_QSGABSTRACTRENDERER_IDX], reinterpret_cast<SbkObject *>(self)));
    int overloadId = -1;
    PythonToCppFunc pythonToCpp{};
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSGAbstractRenderer::setClearColor(QColor)
    if ((pythonToCpp = Shiboken::Conversions::isPythonToCppReferenceConvertible(reinterpret_cast<SbkObjectType *>(SbkPySide2_QtGuiTypes[SBK_QCOLOR_IDX]), (pyArg)))) {
        overloadId = 0; // setClearColor(QColor)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QSGAbstractRendererFunc_setClearColor_TypeError;

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QColor cppArg0_local;
        ::QColor *cppArg0 = &cppArg0_local;
        if (Shiboken::Conversions::isImplicitConversion(reinterpret_cast<SbkObjectType *>(SbkPySide2_QtGuiTypes[SBK_QCOLOR_IDX]), pythonToCpp))
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (!PyErr_Occurred()) {
            // setClearColor(QColor)
            PyThreadState *_save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cppSelf->setClearColor(*cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return {};
    }
    Py_RETURN_NONE;

    Sbk_QSGAbstractRendererFunc_setClearColor_TypeError:
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide2.QtQuick.QSGAbstractRenderer.setClearColor");
        return {};
}

static PyObject *Sbk_QSGAbstractRendererFunc_setClearMode(PyObject *self, PyObject *pyArg)
{
    ::QSGAbstractRenderer *cppSelf = nullptr;
    SBK_UNUSED(cppSelf)
    if (!Shiboken::Object::isValid(self))
        return {};
    cppSelf = reinterpret_cast< ::QSGAbstractRenderer *>(Shiboken::Conversions::cppPointer(SbkPySide2_QtQuickTypes[SBK_QSGABSTRACTRENDERER_IDX], reinterpret_cast<SbkObject *>(self)));
    int overloadId = -1;
    PythonToCppFunc pythonToCpp{};
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSGAbstractRenderer::setClearMode(QFlags<QSGAbstractRenderer::ClearModeBit>)
    if ((pythonToCpp = Shiboken::Conversions::isPythonToCppConvertible(*PepType_SGTP(SbkPySide2_QtQuickTypes[SBK_QFLAGS_QSGABSTRACTRENDERER_CLEARMODEBIT_IDX])->converter, (pyArg)))) {
        overloadId = 0; // setClearMode(QFlags<QSGAbstractRenderer::ClearModeBit>)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QSGAbstractRendererFunc_setClearMode_TypeError;

    // Call function/method
    {
        ::QFlags<QSGAbstractRenderer::ClearModeBit> cppArg0 = QFlags<QSGAbstractRenderer::ClearModeBit>(0);
        pythonToCpp(pyArg, &cppArg0);

        if (!PyErr_Occurred()) {
            // setClearMode(QFlags<QSGAbstractRenderer::ClearModeBit>)
            PyThreadState *_save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cppSelf->setClearMode(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return {};
    }
    Py_RETURN_NONE;

    Sbk_QSGAbstractRendererFunc_setClearMode_TypeError:
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide2.QtQuick.QSGAbstractRenderer.setClearMode");
        return {};
}

static PyObject *Sbk_QSGAbstractRendererFunc_setDeviceRect(PyObject *self, PyObject *pyArg)
{
    ::QSGAbstractRenderer *cppSelf = nullptr;
    SBK_UNUSED(cppSelf)
    if (!Shiboken::Object::isValid(self))
        return {};
    cppSelf = reinterpret_cast< ::QSGAbstractRenderer *>(Shiboken::Conversions::cppPointer(SbkPySide2_QtQuickTypes[SBK_QSGABSTRACTRENDERER_IDX], reinterpret_cast<SbkObject *>(self)));
    int overloadId = -1;
    PythonToCppFunc pythonToCpp{};
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSGAbstractRenderer::setDeviceRect(QRect)
    // 1: QSGAbstractRenderer::setDeviceRect(QSize)
    if ((pythonToCpp = Shiboken::Conversions::isPythonToCppReferenceConvertible(reinterpret_cast<SbkObjectType *>(SbkPySide2_QtCoreTypes[SBK_QSIZE_IDX]), (pyArg)))) {
        overloadId = 1; // setDeviceRect(QSize)
    } else if ((pythonToCpp = Shiboken::Conversions::isPythonToCppReferenceConvertible(reinterpret_cast<SbkObjectType *>(SbkPySide2_QtCoreTypes[SBK_QRECT_IDX]), (pyArg)))) {
        overloadId = 0; // setDeviceRect(QRect)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QSGAbstractRendererFunc_setDeviceRect_TypeError;

    // Call function/method
    switch (overloadId) {
        case 0: // setDeviceRect(const QRect & rect)
        {
            if (!Shiboken::Object::isValid(pyArg))
                return {};
            ::QRect cppArg0_local;
            ::QRect *cppArg0 = &cppArg0_local;
            if (Shiboken::Conversions::isImplicitConversion(reinterpret_cast<SbkObjectType *>(SbkPySide2_QtCoreTypes[SBK_QRECT_IDX]), pythonToCpp))
                pythonToCpp(pyArg, &cppArg0_local);
            else
                pythonToCpp(pyArg, &cppArg0);


            if (!PyErr_Occurred()) {
                // setDeviceRect(QRect)
                PyThreadState *_save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setDeviceRect(*cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
        case 1: // setDeviceRect(const QSize & size)
        {
            if (!Shiboken::Object::isValid(pyArg))
                return {};
            ::QSize cppArg0_local;
            ::QSize *cppArg0 = &cppArg0_local;
            if (Shiboken::Conversions::isImplicitConversion(reinterpret_cast<SbkObjectType *>(SbkPySide2_QtCoreTypes[SBK_QSIZE_IDX]), pythonToCpp))
                pythonToCpp(pyArg, &cppArg0_local);
            else
                pythonToCpp(pyArg, &cppArg0);


            if (!PyErr_Occurred()) {
                // setDeviceRect(QSize)
                PyThreadState *_save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setDeviceRect(*cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
    }

    if (PyErr_Occurred()) {
        return {};
    }
    Py_RETURN_NONE;

    Sbk_QSGAbstractRendererFunc_setDeviceRect_TypeError:
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide2.QtQuick.QSGAbstractRenderer.setDeviceRect");
        return {};
}

static PyObject *Sbk_QSGAbstractRendererFunc_setProjectionMatrix(PyObject *self, PyObject *pyArg)
{
    ::QSGAbstractRenderer *cppSelf = nullptr;
    SBK_UNUSED(cppSelf)
    if (!Shiboken::Object::isValid(self))
        return {};
    cppSelf = reinterpret_cast< ::QSGAbstractRenderer *>(Shiboken::Conversions::cppPointer(SbkPySide2_QtQuickTypes[SBK_QSGABSTRACTRENDERER_IDX], reinterpret_cast<SbkObject *>(self)));
    int overloadId = -1;
    PythonToCppFunc pythonToCpp{};
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSGAbstractRenderer::setProjectionMatrix(QMatrix4x4)
    if ((pythonToCpp = Shiboken::Conversions::isPythonToCppReferenceConvertible(reinterpret_cast<SbkObjectType *>(SbkPySide2_QtGuiTypes[SBK_QMATRIX4X4_IDX]), (pyArg)))) {
        overloadId = 0; // setProjectionMatrix(QMatrix4x4)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QSGAbstractRendererFunc_setProjectionMatrix_TypeError;

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QMatrix4x4 cppArg0_local;
        ::QMatrix4x4 *cppArg0 = &cppArg0_local;
        if (Shiboken::Conversions::isImplicitConversion(reinterpret_cast<SbkObjectType *>(SbkPySide2_QtGuiTypes[SBK_QMATRIX4X4_IDX]), pythonToCpp))
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (!PyErr_Occurred()) {
            // setProjectionMatrix(QMatrix4x4)
            PyThreadState *_save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cppSelf->setProjectionMatrix(*cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return {};
    }
    Py_RETURN_NONE;

    Sbk_QSGAbstractRendererFunc_setProjectionMatrix_TypeError:
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide2.QtQuick.QSGAbstractRenderer.setProjectionMatrix");
        return {};
}

static PyObject *Sbk_QSGAbstractRendererFunc_setProjectionMatrixToRect(PyObject *self, PyObject *pyArg)
{
    ::QSGAbstractRenderer *cppSelf = nullptr;
    SBK_UNUSED(cppSelf)
    if (!Shiboken::Object::isValid(self))
        return {};
    cppSelf = reinterpret_cast< ::QSGAbstractRenderer *>(Shiboken::Conversions::cppPointer(SbkPySide2_QtQuickTypes[SBK_QSGABSTRACTRENDERER_IDX], reinterpret_cast<SbkObject *>(self)));
    int overloadId = -1;
    PythonToCppFunc pythonToCpp{};
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSGAbstractRenderer::setProjectionMatrixToRect(QRectF)
    if ((pythonToCpp = Shiboken::Conversions::isPythonToCppReferenceConvertible(reinterpret_cast<SbkObjectType *>(SbkPySide2_QtCoreTypes[SBK_QRECTF_IDX]), (pyArg)))) {
        overloadId = 0; // setProjectionMatrixToRect(QRectF)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QSGAbstractRendererFunc_setProjectionMatrixToRect_TypeError;

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QRectF cppArg0_local;
        ::QRectF *cppArg0 = &cppArg0_local;
        if (Shiboken::Conversions::isImplicitConversion(reinterpret_cast<SbkObjectType *>(SbkPySide2_QtCoreTypes[SBK_QRECTF_IDX]), pythonToCpp))
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (!PyErr_Occurred()) {
            // setProjectionMatrixToRect(QRectF)
            PyThreadState *_save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cppSelf->setProjectionMatrixToRect(*cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return {};
    }
    Py_RETURN_NONE;

    Sbk_QSGAbstractRendererFunc_setProjectionMatrixToRect_TypeError:
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide2.QtQuick.QSGAbstractRenderer.setProjectionMatrixToRect");
        return {};
}

static PyObject *Sbk_QSGAbstractRendererFunc_setViewportRect(PyObject *self, PyObject *pyArg)
{
    ::QSGAbstractRenderer *cppSelf = nullptr;
    SBK_UNUSED(cppSelf)
    if (!Shiboken::Object::isValid(self))
        return {};
    cppSelf = reinterpret_cast< ::QSGAbstractRenderer *>(Shiboken::Conversions::cppPointer(SbkPySide2_QtQuickTypes[SBK_QSGABSTRACTRENDERER_IDX], reinterpret_cast<SbkObject *>(self)));
    int overloadId = -1;
    PythonToCppFunc pythonToCpp{};
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSGAbstractRenderer::setViewportRect(QRect)
    // 1: QSGAbstractRenderer::setViewportRect(QSize)
    if ((pythonToCpp = Shiboken::Conversions::isPythonToCppReferenceConvertible(reinterpret_cast<SbkObjectType *>(SbkPySide2_QtCoreTypes[SBK_QSIZE_IDX]), (pyArg)))) {
        overloadId = 1; // setViewportRect(QSize)
    } else if ((pythonToCpp = Shiboken::Conversions::isPythonToCppReferenceConvertible(reinterpret_cast<SbkObjectType *>(SbkPySide2_QtCoreTypes[SBK_QRECT_IDX]), (pyArg)))) {
        overloadId = 0; // setViewportRect(QRect)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QSGAbstractRendererFunc_setViewportRect_TypeError;

    // Call function/method
    switch (overloadId) {
        case 0: // setViewportRect(const QRect & rect)
        {
            if (!Shiboken::Object::isValid(pyArg))
                return {};
            ::QRect cppArg0_local;
            ::QRect *cppArg0 = &cppArg0_local;
            if (Shiboken::Conversions::isImplicitConversion(reinterpret_cast<SbkObjectType *>(SbkPySide2_QtCoreTypes[SBK_QRECT_IDX]), pythonToCpp))
                pythonToCpp(pyArg, &cppArg0_local);
            else
                pythonToCpp(pyArg, &cppArg0);


            if (!PyErr_Occurred()) {
                // setViewportRect(QRect)
                PyThreadState *_save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setViewportRect(*cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
        case 1: // setViewportRect(const QSize & size)
        {
            if (!Shiboken::Object::isValid(pyArg))
                return {};
            ::QSize cppArg0_local;
            ::QSize *cppArg0 = &cppArg0_local;
            if (Shiboken::Conversions::isImplicitConversion(reinterpret_cast<SbkObjectType *>(SbkPySide2_QtCoreTypes[SBK_QSIZE_IDX]), pythonToCpp))
                pythonToCpp(pyArg, &cppArg0_local);
            else
                pythonToCpp(pyArg, &cppArg0);


            if (!PyErr_Occurred()) {
                // setViewportRect(QSize)
                PyThreadState *_save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setViewportRect(*cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
    }

    if (PyErr_Occurred()) {
        return {};
    }
    Py_RETURN_NONE;

    Sbk_QSGAbstractRendererFunc_setViewportRect_TypeError:
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide2.QtQuick.QSGAbstractRenderer.setViewportRect");
        return {};
}

static PyObject *Sbk_QSGAbstractRendererFunc_viewportRect(PyObject *self)
{
    ::QSGAbstractRenderer *cppSelf = nullptr;
    SBK_UNUSED(cppSelf)
    if (!Shiboken::Object::isValid(self))
        return {};
    cppSelf = reinterpret_cast< ::QSGAbstractRenderer *>(Shiboken::Conversions::cppPointer(SbkPySide2_QtQuickTypes[SBK_QSGABSTRACTRENDERER_IDX], reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};

    // Call function/method
    {

        if (!PyErr_Occurred()) {
            // viewportRect()const
            QRect cppResult = const_cast<const ::QSGAbstractRenderer *>(cppSelf)->viewportRect();
            pyResult = Shiboken::Conversions::copyToPython(reinterpret_cast<SbkObjectType *>(SbkPySide2_QtCoreTypes[SBK_QRECT_IDX]), &cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyMethodDef Sbk_QSGAbstractRenderer_methods[] = {
    {"clearColor", reinterpret_cast<PyCFunction>(Sbk_QSGAbstractRendererFunc_clearColor), METH_NOARGS},
    {"clearMode", reinterpret_cast<PyCFunction>(Sbk_QSGAbstractRendererFunc_clearMode), METH_NOARGS},
    {"deviceRect", reinterpret_cast<PyCFunction>(Sbk_QSGAbstractRendererFunc_deviceRect), METH_NOARGS},
    {"nodeChanged", reinterpret_cast<PyCFunction>(Sbk_QSGAbstractRendererFunc_nodeChanged), METH_VARARGS},
    {"projectionMatrix", reinterpret_cast<PyCFunction>(Sbk_QSGAbstractRendererFunc_projectionMatrix), METH_NOARGS},
    {"renderScene", reinterpret_cast<PyCFunction>(Sbk_QSGAbstractRendererFunc_renderScene), METH_VARARGS|METH_KEYWORDS},
    {"setClearColor", reinterpret_cast<PyCFunction>(Sbk_QSGAbstractRendererFunc_setClearColor), METH_O},
    {"setClearMode", reinterpret_cast<PyCFunction>(Sbk_QSGAbstractRendererFunc_setClearMode), METH_O},
    {"setDeviceRect", reinterpret_cast<PyCFunction>(Sbk_QSGAbstractRendererFunc_setDeviceRect), METH_O},
    {"setProjectionMatrix", reinterpret_cast<PyCFunction>(Sbk_QSGAbstractRendererFunc_setProjectionMatrix), METH_O},
    {"setProjectionMatrixToRect", reinterpret_cast<PyCFunction>(Sbk_QSGAbstractRendererFunc_setProjectionMatrixToRect), METH_O},
    {"setViewportRect", reinterpret_cast<PyCFunction>(Sbk_QSGAbstractRendererFunc_setViewportRect), METH_O},
    {"viewportRect", reinterpret_cast<PyCFunction>(Sbk_QSGAbstractRendererFunc_viewportRect), METH_NOARGS},

    {nullptr, nullptr} // Sentinel
};

} // extern "C"

static int Sbk_QSGAbstractRenderer_traverse(PyObject *self, visitproc visit, void *arg)
{
    return reinterpret_cast<PyTypeObject *>(SbkObject_TypeF())->tp_traverse(self, visit, arg);
}
static int Sbk_QSGAbstractRenderer_clear(PyObject *self)
{
    return reinterpret_cast<PyTypeObject *>(SbkObject_TypeF())->tp_clear(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType *_Sbk_QSGAbstractRenderer_Type = nullptr;
static SbkObjectType *Sbk_QSGAbstractRenderer_TypeF(void)
{
    return _Sbk_QSGAbstractRenderer_Type;
}

static PyType_Slot Sbk_QSGAbstractRenderer_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_repr,        nullptr},
    {Py_tp_hash,        nullptr},
    {Py_tp_call,        nullptr},
    {Py_tp_str,         nullptr},
    {Py_tp_getattro,    nullptr},
    {Py_tp_setattro,    nullptr},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QSGAbstractRenderer_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QSGAbstractRenderer_clear)},
    {Py_tp_richcompare, nullptr},
    {Py_tp_iter,        nullptr},
    {Py_tp_iternext,    nullptr},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QSGAbstractRenderer_methods)},
    {Py_tp_getset,      nullptr},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QSGAbstractRenderer_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObjectTpNew)},
    {0, nullptr}
};
static PyType_Spec Sbk_QSGAbstractRenderer_spec = {
    "PySide2.QtQuick.QSGAbstractRenderer",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_GC,
    Sbk_QSGAbstractRenderer_slots
};

} //extern "C"

static void *Sbk_QSGAbstractRenderer_typeDiscovery(void *cptr, SbkObjectType *instanceType)
{
    if (instanceType == reinterpret_cast<SbkObjectType *>(Shiboken::SbkType< ::QObject >()))
        return dynamic_cast< ::QSGAbstractRenderer *>(reinterpret_cast< ::QObject *>(cptr));
    return {};
}

PyObject * SbkPySide2_QtQuick_QSGAbstractRenderer_ClearModeBit___and__(PyObject *self, PyObject *pyArg)
{
    ::QSGAbstractRenderer::ClearMode cppResult, cppSelf, cppArg;
#ifdef IS_PY3K
    cppSelf = static_cast<::QSGAbstractRenderer::ClearMode>(int(PyLong_AsLong(self)));
    cppArg = static_cast<QSGAbstractRenderer::ClearMode>(int(PyLong_AsLong(pyArg)));
#else
    cppSelf = static_cast<::QSGAbstractRenderer::ClearMode>(int(PyInt_AsLong(self)));
    cppArg = static_cast<QSGAbstractRenderer::ClearMode>(int(PyInt_AsLong(pyArg)));
#endif

    cppResult = cppSelf & cppArg;
    return Shiboken::Conversions::copyToPython(*PepType_SGTP(SbkPySide2_QtQuickTypes[SBK_QFLAGS_QSGABSTRACTRENDERER_CLEARMODEBIT_IDX])->converter, &cppResult);
}

PyObject * SbkPySide2_QtQuick_QSGAbstractRenderer_ClearModeBit___or__(PyObject *self, PyObject *pyArg)
{
    ::QSGAbstractRenderer::ClearMode cppResult, cppSelf, cppArg;
#ifdef IS_PY3K
    cppSelf = static_cast<::QSGAbstractRenderer::ClearMode>(int(PyLong_AsLong(self)));
    cppArg = static_cast<QSGAbstractRenderer::ClearMode>(int(PyLong_AsLong(pyArg)));
#else
    cppSelf = static_cast<::QSGAbstractRenderer::ClearMode>(int(PyInt_AsLong(self)));
    cppArg = static_cast<QSGAbstractRenderer::ClearMode>(int(PyInt_AsLong(pyArg)));
#endif

    cppResult = cppSelf | cppArg;
    return Shiboken::Conversions::copyToPython(*PepType_SGTP(SbkPySide2_QtQuickTypes[SBK_QFLAGS_QSGABSTRACTRENDERER_CLEARMODEBIT_IDX])->converter, &cppResult);
}

PyObject * SbkPySide2_QtQuick_QSGAbstractRenderer_ClearModeBit___xor__(PyObject *self, PyObject *pyArg)
{
    ::QSGAbstractRenderer::ClearMode cppResult, cppSelf, cppArg;
#ifdef IS_PY3K
    cppSelf = static_cast<::QSGAbstractRenderer::ClearMode>(int(PyLong_AsLong(self)));
    cppArg = static_cast<QSGAbstractRenderer::ClearMode>(int(PyLong_AsLong(pyArg)));
#else
    cppSelf = static_cast<::QSGAbstractRenderer::ClearMode>(int(PyInt_AsLong(self)));
    cppArg = static_cast<QSGAbstractRenderer::ClearMode>(int(PyInt_AsLong(pyArg)));
#endif

    cppResult = cppSelf ^ cppArg;
    return Shiboken::Conversions::copyToPython(*PepType_SGTP(SbkPySide2_QtQuickTypes[SBK_QFLAGS_QSGABSTRACTRENDERER_CLEARMODEBIT_IDX])->converter, &cppResult);
}

PyObject *SbkPySide2_QtQuick_QSGAbstractRenderer_ClearModeBit___invert__(PyObject *self, PyObject *pyArg)
{
    ::QSGAbstractRenderer::ClearMode cppSelf;
    Shiboken::Conversions::pythonToCppCopy(*PepType_SGTP(SbkPySide2_QtQuickTypes[SBK_QFLAGS_QSGABSTRACTRENDERER_CLEARMODEBIT_IDX])->converter, self, &cppSelf);
    ::QSGAbstractRenderer::ClearMode cppResult = ~cppSelf;
    return Shiboken::Conversions::copyToPython(*PepType_SGTP(SbkPySide2_QtQuickTypes[SBK_QFLAGS_QSGABSTRACTRENDERER_CLEARMODEBIT_IDX])->converter, &cppResult);
}

static PyObject *SbkPySide2_QtQuick_QSGAbstractRenderer_ClearModeBit_long(PyObject *self)
{
    int val;
    Shiboken::Conversions::pythonToCppCopy(*PepType_SGTP(SbkPySide2_QtQuickTypes[SBK_QFLAGS_QSGABSTRACTRENDERER_CLEARMODEBIT_IDX])->converter, self, &val);
    return Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &val);
}
static int SbkPySide2_QtQuick_QSGAbstractRenderer_ClearModeBit__nonzero(PyObject *self)
{
    int val;
    Shiboken::Conversions::pythonToCppCopy(*PepType_SGTP(SbkPySide2_QtQuickTypes[SBK_QFLAGS_QSGABSTRACTRENDERER_CLEARMODEBIT_IDX])->converter, self, &val);
    return val != 0;
}

static PyType_Slot SbkPySide2_QtQuick_QSGAbstractRenderer_ClearModeBit_number_slots[] = {
#ifdef IS_PY3K
    {Py_nb_bool,    (void *)SbkPySide2_QtQuick_QSGAbstractRenderer_ClearModeBit__nonzero},
#else
    {Py_nb_nonzero, (void *)SbkPySide2_QtQuick_QSGAbstractRenderer_ClearModeBit__nonzero},
    {Py_nb_long,    (void *)SbkPySide2_QtQuick_QSGAbstractRenderer_ClearModeBit_long},
#endif
    {Py_nb_invert,  (void *)SbkPySide2_QtQuick_QSGAbstractRenderer_ClearModeBit___invert__},
    {Py_nb_and,     (void *)SbkPySide2_QtQuick_QSGAbstractRenderer_ClearModeBit___and__},
    {Py_nb_xor,     (void *)SbkPySide2_QtQuick_QSGAbstractRenderer_ClearModeBit___xor__},
    {Py_nb_or,      (void *)SbkPySide2_QtQuick_QSGAbstractRenderer_ClearModeBit___or__},
    {Py_nb_int,     (void *)SbkPySide2_QtQuick_QSGAbstractRenderer_ClearModeBit_long},
#ifndef IS_PY3K
    {Py_nb_long,    (void *)SbkPySide2_QtQuick_QSGAbstractRenderer_ClearModeBit_long},
#endif
    {0, nullptr} // sentinel
};



// Type conversion functions.

// Python to C++ enum conversion.
static void QSGAbstractRenderer_ClearModeBit_PythonToCpp_QSGAbstractRenderer_ClearModeBit(PyObject *pyIn, void *cppOut) {
    *reinterpret_cast<::QSGAbstractRenderer::ClearModeBit *>(cppOut) =
        static_cast<::QSGAbstractRenderer::ClearModeBit>(Shiboken::Enum::getValue(pyIn));

}
static PythonToCppFunc is_QSGAbstractRenderer_ClearModeBit_PythonToCpp_QSGAbstractRenderer_ClearModeBit_Convertible(PyObject *pyIn) {
    if (PyObject_TypeCheck(pyIn, SbkPySide2_QtQuickTypes[SBK_QSGABSTRACTRENDERER_CLEARMODEBIT_IDX]))
        return QSGAbstractRenderer_ClearModeBit_PythonToCpp_QSGAbstractRenderer_ClearModeBit;
    return {};
}
static PyObject *QSGAbstractRenderer_ClearModeBit_CppToPython_QSGAbstractRenderer_ClearModeBit(const void *cppIn) {
    const int castCppIn = int(*reinterpret_cast<const ::QSGAbstractRenderer::ClearModeBit *>(cppIn));
    return Shiboken::Enum::newItem(SbkPySide2_QtQuickTypes[SBK_QSGABSTRACTRENDERER_CLEARMODEBIT_IDX], castCppIn);

}

static void QFlags_QSGAbstractRenderer_ClearModeBit__PythonToCpp_QFlags_QSGAbstractRenderer_ClearModeBit_(PyObject *pyIn, void *cppOut) {
    *reinterpret_cast<::QFlags<QSGAbstractRenderer::ClearModeBit> *>(cppOut) =
        ::QFlags<QSGAbstractRenderer::ClearModeBit>(QFlag(int(PySide::QFlags::getValue(reinterpret_cast<PySideQFlagsObject *>(pyIn)))));

}
static PythonToCppFunc is_QFlags_QSGAbstractRenderer_ClearModeBit__PythonToCpp_QFlags_QSGAbstractRenderer_ClearModeBit__Convertible(PyObject *pyIn) {
    if (PyObject_TypeCheck(pyIn, SbkPySide2_QtQuickTypes[SBK_QFLAGS_QSGABSTRACTRENDERER_CLEARMODEBIT_IDX]))
        return QFlags_QSGAbstractRenderer_ClearModeBit__PythonToCpp_QFlags_QSGAbstractRenderer_ClearModeBit_;
    return {};
}
static PyObject *QFlags_QSGAbstractRenderer_ClearModeBit__CppToPython_QFlags_QSGAbstractRenderer_ClearModeBit_(const void *cppIn) {
    const int castCppIn = int(*reinterpret_cast<const ::QFlags<QSGAbstractRenderer::ClearModeBit> *>(cppIn));
    return reinterpret_cast<PyObject *>(PySide::QFlags::newObject(castCppIn, SbkPySide2_QtQuickTypes[SBK_QFLAGS_QSGABSTRACTRENDERER_CLEARMODEBIT_IDX]));

}

static void QSGAbstractRenderer_ClearModeBit_PythonToCpp_QFlags_QSGAbstractRenderer_ClearModeBit_(PyObject *pyIn, void *cppOut) {
    *reinterpret_cast<::QFlags<QSGAbstractRenderer::ClearModeBit> *>(cppOut) =
        ::QFlags<QSGAbstractRenderer::ClearModeBit>(QFlag(int(Shiboken::Enum::getValue(pyIn))));

}
static PythonToCppFunc is_QSGAbstractRenderer_ClearModeBit_PythonToCpp_QFlags_QSGAbstractRenderer_ClearModeBit__Convertible(PyObject *pyIn) {
    if (PyObject_TypeCheck(pyIn, SbkPySide2_QtQuickTypes[SBK_QSGABSTRACTRENDERER_CLEARMODEBIT_IDX]))
        return QSGAbstractRenderer_ClearModeBit_PythonToCpp_QFlags_QSGAbstractRenderer_ClearModeBit_;
    return {};
}
static void number_PythonToCpp_QFlags_QSGAbstractRenderer_ClearModeBit_(PyObject *pyIn, void *cppOut) {
    Shiboken::AutoDecRef pyLong(PyNumber_Long(pyIn));
    *reinterpret_cast<::QFlags<QSGAbstractRenderer::ClearModeBit> *>(cppOut) =
        ::QFlags<QSGAbstractRenderer::ClearModeBit>(QFlag(int(PyLong_AsLong(pyLong.object()))));

}
static PythonToCppFunc is_number_PythonToCpp_QFlags_QSGAbstractRenderer_ClearModeBit__Convertible(PyObject *pyIn) {
    if (PyNumber_Check(pyIn) && PyObject_TypeCheck(pyIn, SbkPySide2_QtQuickTypes[SBK_QSGABSTRACTRENDERER_CLEARMODEBIT_IDX]))
        return number_PythonToCpp_QFlags_QSGAbstractRenderer_ClearModeBit_;
    return {};
}
// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QSGAbstractRenderer_PythonToCpp_QSGAbstractRenderer_PTR(PyObject *pyIn, void *cppOut) {
    Shiboken::Conversions::pythonToCppPointer(Sbk_QSGAbstractRenderer_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QSGAbstractRenderer_PythonToCpp_QSGAbstractRenderer_PTR_Convertible(PyObject *pyIn) {
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, reinterpret_cast<PyTypeObject *>(Sbk_QSGAbstractRenderer_TypeF())))
        return QSGAbstractRenderer_PythonToCpp_QSGAbstractRenderer_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QSGAbstractRenderer_PTR_CppToPython_QSGAbstractRenderer(const void *cppIn) {
    return PySide::getWrapperForQObject(reinterpret_cast<::QSGAbstractRenderer *>(const_cast<void *>(cppIn)), Sbk_QSGAbstractRenderer_TypeF());

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
static const char *QSGAbstractRenderer_SignatureStrings[] = {
    "PySide2.QtQuick.QSGAbstractRenderer(parent:PySide2.QtCore.QObject=nullptr)",
    "PySide2.QtQuick.QSGAbstractRenderer.clearColor()->PySide2.QtGui.QColor",
    "PySide2.QtQuick.QSGAbstractRenderer.clearMode()->PySide2.QtQuick.QSGAbstractRenderer.ClearMode",
    "PySide2.QtQuick.QSGAbstractRenderer.deviceRect()->PySide2.QtCore.QRect",
    "PySide2.QtQuick.QSGAbstractRenderer.nodeChanged(node:PySide2.QtQuick.QSGNode,state:PySide2.QtQuick.QSGNode.DirtyState)",
    "PySide2.QtQuick.QSGAbstractRenderer.projectionMatrix()->PySide2.QtGui.QMatrix4x4",
    "PySide2.QtQuick.QSGAbstractRenderer.renderScene(fboId:unsigned int=0)",
    "PySide2.QtQuick.QSGAbstractRenderer.setClearColor(color:PySide2.QtGui.QColor)",
    "PySide2.QtQuick.QSGAbstractRenderer.setClearMode(mode:PySide2.QtQuick.QSGAbstractRenderer.ClearMode)",
    "1:PySide2.QtQuick.QSGAbstractRenderer.setDeviceRect(rect:PySide2.QtCore.QRect)",
    "0:PySide2.QtQuick.QSGAbstractRenderer.setDeviceRect(size:PySide2.QtCore.QSize)",
    "PySide2.QtQuick.QSGAbstractRenderer.setProjectionMatrix(matrix:PySide2.QtGui.QMatrix4x4)",
    "PySide2.QtQuick.QSGAbstractRenderer.setProjectionMatrixToRect(rect:PySide2.QtCore.QRectF)",
    "1:PySide2.QtQuick.QSGAbstractRenderer.setViewportRect(rect:PySide2.QtCore.QRect)",
    "0:PySide2.QtQuick.QSGAbstractRenderer.setViewportRect(size:PySide2.QtCore.QSize)",
    "PySide2.QtQuick.QSGAbstractRenderer.viewportRect()->PySide2.QtCore.QRect",
    nullptr}; // Sentinel

void init_QSGAbstractRenderer(PyObject *module)
{
    _Sbk_QSGAbstractRenderer_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QSGAbstractRenderer",
        "QSGAbstractRenderer*",
        &Sbk_QSGAbstractRenderer_spec,
        QSGAbstractRenderer_SignatureStrings,
        &Shiboken::callCppDestructor< ::QSGAbstractRenderer >,
        reinterpret_cast<SbkObjectType *>(SbkPySide2_QtCoreTypes[SBK_QOBJECT_IDX]),
        0,
        0    );
    
    SbkPySide2_QtQuickTypes[SBK_QSGABSTRACTRENDERER_IDX]
        = reinterpret_cast<PyTypeObject *>(Sbk_QSGAbstractRenderer_TypeF());

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(Sbk_QSGAbstractRenderer_TypeF(),
        QSGAbstractRenderer_PythonToCpp_QSGAbstractRenderer_PTR,
        is_QSGAbstractRenderer_PythonToCpp_QSGAbstractRenderer_PTR_Convertible,
        QSGAbstractRenderer_PTR_CppToPython_QSGAbstractRenderer);

    Shiboken::Conversions::registerConverterName(converter, "QSGAbstractRenderer");
    Shiboken::Conversions::registerConverterName(converter, "QSGAbstractRenderer*");
    Shiboken::Conversions::registerConverterName(converter, "QSGAbstractRenderer&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QSGAbstractRenderer).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(::QSGAbstractRendererWrapper).name());


    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(Sbk_QSGAbstractRenderer_TypeF(), &Sbk_QSGAbstractRenderer_typeDiscovery);

    // Initialization of enums.

    // Initialization of enum 'ClearModeBit'.
    SbkPySide2_QtQuickTypes[SBK_QFLAGS_QSGABSTRACTRENDERER_CLEARMODEBIT_IDX] = PySide::QFlags::create("PySide2.QtQuick.QSGAbstractRenderer.ClearMode", SbkPySide2_QtQuick_QSGAbstractRenderer_ClearModeBit_number_slots);
    SbkPySide2_QtQuickTypes[SBK_QSGABSTRACTRENDERER_CLEARMODEBIT_IDX] = Shiboken::Enum::createScopedEnum(Sbk_QSGAbstractRenderer_TypeF(),
        "ClearModeBit",
        "PySide2.QtQuick.QSGAbstractRenderer.ClearModeBit",
        "QSGAbstractRenderer::ClearModeBit",
        SbkPySide2_QtQuickTypes[SBK_QFLAGS_QSGABSTRACTRENDERER_CLEARMODEBIT_IDX]);
    if (!SbkPySide2_QtQuickTypes[SBK_QSGABSTRACTRENDERER_CLEARMODEBIT_IDX])
        return;

    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide2_QtQuickTypes[SBK_QSGABSTRACTRENDERER_CLEARMODEBIT_IDX],
        Sbk_QSGAbstractRenderer_TypeF(), "ClearColorBuffer", (long) QSGAbstractRenderer::ClearModeBit::ClearColorBuffer))
        return;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide2_QtQuickTypes[SBK_QSGABSTRACTRENDERER_CLEARMODEBIT_IDX],
        Sbk_QSGAbstractRenderer_TypeF(), "ClearDepthBuffer", (long) QSGAbstractRenderer::ClearModeBit::ClearDepthBuffer))
        return;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide2_QtQuickTypes[SBK_QSGABSTRACTRENDERER_CLEARMODEBIT_IDX],
        Sbk_QSGAbstractRenderer_TypeF(), "ClearStencilBuffer", (long) QSGAbstractRenderer::ClearModeBit::ClearStencilBuffer))
        return;
    // Register converter for enum 'QSGAbstractRenderer::ClearModeBit'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(SbkPySide2_QtQuickTypes[SBK_QSGABSTRACTRENDERER_CLEARMODEBIT_IDX],
            QSGAbstractRenderer_ClearModeBit_CppToPython_QSGAbstractRenderer_ClearModeBit);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            QSGAbstractRenderer_ClearModeBit_PythonToCpp_QSGAbstractRenderer_ClearModeBit,
            is_QSGAbstractRenderer_ClearModeBit_PythonToCpp_QSGAbstractRenderer_ClearModeBit_Convertible);
        Shiboken::Enum::setTypeConverter(SbkPySide2_QtQuickTypes[SBK_QSGABSTRACTRENDERER_CLEARMODEBIT_IDX], converter);
        Shiboken::Conversions::registerConverterName(converter, "QSGAbstractRenderer::ClearModeBit");
        Shiboken::Conversions::registerConverterName(converter, "ClearModeBit");
    }
    // Register converter for flag 'QFlags<QSGAbstractRenderer::ClearModeBit>'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(SbkPySide2_QtQuickTypes[SBK_QFLAGS_QSGABSTRACTRENDERER_CLEARMODEBIT_IDX],
            QFlags_QSGAbstractRenderer_ClearModeBit__CppToPython_QFlags_QSGAbstractRenderer_ClearModeBit_);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            QSGAbstractRenderer_ClearModeBit_PythonToCpp_QFlags_QSGAbstractRenderer_ClearModeBit_,
            is_QSGAbstractRenderer_ClearModeBit_PythonToCpp_QFlags_QSGAbstractRenderer_ClearModeBit__Convertible);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            QFlags_QSGAbstractRenderer_ClearModeBit__PythonToCpp_QFlags_QSGAbstractRenderer_ClearModeBit_,
            is_QFlags_QSGAbstractRenderer_ClearModeBit__PythonToCpp_QFlags_QSGAbstractRenderer_ClearModeBit__Convertible);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            number_PythonToCpp_QFlags_QSGAbstractRenderer_ClearModeBit_,
            is_number_PythonToCpp_QFlags_QSGAbstractRenderer_ClearModeBit__Convertible);
        Shiboken::Enum::setTypeConverter(SbkPySide2_QtQuickTypes[SBK_QFLAGS_QSGABSTRACTRENDERER_CLEARMODEBIT_IDX], converter);
        Shiboken::Conversions::registerConverterName(converter, "QSGAbstractRenderer::ClearMode");
        Shiboken::Conversions::registerConverterName(converter, "ClearMode");
    }
    // End of 'ClearModeBit' enum/flags.

    PySide::Signal::registerSignals(Sbk_QSGAbstractRenderer_TypeF(), &::QSGAbstractRenderer::staticMetaObject);

    qRegisterMetaType< ::QSGAbstractRenderer::ClearModeBit >("QSGAbstractRenderer::ClearModeBit");
    qRegisterMetaType< ::QSGAbstractRenderer::ClearMode >("QSGAbstractRenderer::ClearMode");
    Shiboken::ObjectType::setSubTypeInitHook(Sbk_QSGAbstractRenderer_TypeF(), &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(Sbk_QSGAbstractRenderer_TypeF(), &::QSGAbstractRenderer::staticMetaObject, sizeof(::QSGAbstractRenderer));
}
